"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FieldsInterceptor = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const operators_1 = require("rxjs/operators");
let FieldsInterceptor = class FieldsInterceptor {
    intercept(context, next) {
        const contextType = context.getType();
        if (!["http", "https"].includes(contextType)) {
            return next.handle();
        }
        const request = context.getArgByIndex(0);
        return next
            .handle()
            .pipe((0, operators_1.map)((resultRef) => {
            if (typeof resultRef !== 'object') {
                return resultRef;
            }
            const result = JSON.parse(JSON.stringify(resultRef));
            const fieldsArgument = request.query.fields;
            if (fieldsArgument) {
                const fields = Array.isArray(fieldsArgument) ? fieldsArgument : fieldsArgument.split(',');
                if (Array.isArray(result)) {
                    for (const item of result) {
                        this.transformItem(item, fields);
                    }
                }
                else {
                    this.transformItem(result, fields);
                }
            }
            return result;
        }));
    }
    transformItem(item, fields) {
        for (const key of Object.keys(item)) {
            if (!fields.includes(key)) {
                delete item[key];
            }
        }
    }
};
FieldsInterceptor = tslib_1.__decorate([
    (0, common_1.Injectable)()
], FieldsInterceptor);
exports.FieldsInterceptor = FieldsInterceptor;
//# sourceMappingURL=fields.interceptor.js.map